==> connector-client-1.0.0-20230323.092234-1-sources.jar: com/daas/nros/connector/burgeon/model/vo/AddConsumeRequestVO.java <==
package com.daas.nros.connector.burgeon.model.vo;

import com.bizvane.connectorservice.entity.icrm.ConsumeDetail;
import com.bizvane.connectorservice.entity.icrm.ConsumePayVO;
import com.bizvane.connectorservice.entity.icrm.ConsumeVO;
import com.bizvane.connectorservice.entity.icrm.IcrmBaseModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

/**
 * @author admin
 * @date
 */
public class AddConsumeRequestVO extends IcrmBaseModel {

    @ApiModelProperty(
            value = "",
            name = "consume",
            required = true,
            example = ""
    )
    private ConsumeVO consume;

    @ApiModelProperty(
            value = "消费商品信息",
            name = "consume_detail",
            required = true,
            example = ""
    )
    private List<com.bizvane.connectorservice.entity.icrm.ConsumeDetail> consume_detail;

    @ApiModelProperty(
            value = "支付信息",
            name = "consume_paylist",
            required = true,
            example = ""
    )
    private List<com.bizvane.connectorservice.entity.icrm.ConsumePayVO> consume_paylist;

    /**
     * 不必传
     */
    private Integer sets;
    /**
     * 不必传
     */
    private String e3_consume_data;


    public ConsumeVO getConsume() {
        return consume;
    }

    public void setConsume(ConsumeVO consume) {
        this.consume = consume;
    }

    public List<com.bizvane.connectorservice.entity.icrm.ConsumeDetail> getConsume_detail() {
        return consume_detail;
    }

    public void setConsume_detail(List<ConsumeDetail> consume_detail) {
        this.consume_detail = consume_detail;
    }

    public List<com.bizvane.connectorservice.entity.icrm.ConsumePayVO> getConsume_paylist() {
        return consume_paylist;
    }

    public void setConsume_paylist(List<ConsumePayVO> consume_paylist) {
        this.consume_paylist = consume_paylist;
    }

    public Integer getSets() {
        return sets;
    }

    public void setSets(Integer sets) {
        this.sets = sets;
    }

    public String getE3_consume_data() {
        return e3_consume_data;
    }

    public void setE3_consume_data(String e3_consume_data) {
        this.e3_consume_data = e3_consume_data;
    }

    @Override
    public String toString() {
        return "AddConsumeRequestVO{" +
                "consume=" + consume +
                ", consume_detail=" + consume_detail +
                ", consume_paylist=" + consume_paylist +
                ", sets=" + sets +
                ", e3_consume_data='" + e3_consume_data + '\'' +
                '}';
    }
}

==> connector-client-1.0.0-20230324.090846-5-sources.jar: com/daas/nros/connector/burgeon/model/vo/AddConsumeRequestVO.java <==
package com.daas.nros.connector.burgeon.model.vo;

import io.swagger.annotations.ApiModelProperty;

import java.util.List;

/**
 * @author admin
 * @date
 */
public class AddConsumeRequestVO extends IcrmBaseModel {

    @ApiModelProperty(
            value = "",
            name = "consume",
            required = true,
            example = ""
    )
    private ConsumeVO consume;

    @ApiModelProperty(
            value = "消费商品信息",
            name = "consume_detail",
            required = true,
            example = ""
    )
    private List<ConsumeDetail> consume_detail;

    @ApiModelProperty(
            value = "支付信息",
            name = "consume_paylist",
            required = true,
            example = ""
    )
    private List<ConsumePayVO> consume_paylist;

    /**
     * 不必传
     */
    private Integer sets;
    /**
     * 不必传
     */
    private String e3_consume_data;


    public ConsumeVO getConsume() {
        return consume;
    }

    public void setConsume(ConsumeVO consume) {
        this.consume = consume;
    }

    public List<ConsumeDetail> getConsume_detail() {
        return consume_detail;
    }

    public void setConsume_detail(List<ConsumeDetail> consume_detail) {
        this.consume_detail = consume_detail;
    }

    public List<ConsumePayVO> getConsume_paylist() {
        return consume_paylist;
    }

    public void setConsume_paylist(List<ConsumePayVO> consume_paylist) {
        this.consume_paylist = consume_paylist;
    }

    public Integer getSets() {
        return sets;
    }

    public void setSets(Integer sets) {
        this.sets = sets;
    }

    public String getE3_consume_data() {
        return e3_consume_data;
    }

    public void setE3_consume_data(String e3_consume_data) {
        this.e3_consume_data = e3_consume_data;
    }

    @Override
    public String toString() {
        return "AddConsumeRequestVO{" +
                "consume=" + consume +
                ", consume_detail=" + consume_detail +
                ", consume_paylist=" + consume_paylist +
                ", sets=" + sets +
                ", e3_consume_data='" + e3_consume_data + '\'' +
                '}';
    }
}
